package PNI::GUI::Tk;

use Tk;    # it is enough say "use Tk" just once

our $VERSION = '0.14';

__END__

=head1 NAME

PNI::GUI::Tk - Perl Node Interface GUI, implemented with Tk

=SEE ALSO

L<PNI>

L<PNI::GUI::Tk::App>

L<pniguitk>

L<Tk>

=head1 AUTHOR

G. Casati , E<lt>fibo@cpan.orgE<gt>

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2009-2011, Gianluca Casati

This program is free software, you can redistribute it and/or modify it
under the same terms of the Artistic License version 2.0 .

=cut

